{
  description = "System Configuration Flake";

  
  outputs = inputs@{ 
    nixpkgs,
    nixos-hardware,
    home-manager,
    osu-nixos,
    ...
  } : {

    nixosConfigurations = {
      malachite = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [

          ./packages/default.nix
          ./hosts/malachite/default.nix
          ./users/stitchynyan/default.nix

          home-manager.nixosModules.home-manager
          {
             home-manager.extraSpecialArgs = {inherit inputs;};
             home-manager.useGlobalPkgs = true;
             home-manager.useUserPackages = true;
             home-manager.users.stitchynyan = import ./users/stitchynyan/home.nix;
          }
        ];
      };
      scarab = nixpkgs.lib.nixosSystem {
        system = "aarch64-linux";
        modules = [
          { _module.args = { inherit inputs; }; }
          (import "${inputs.mobile-nixos}/lib/configuration.nix" {
            device = "oneplus-enchilada";
          })
          ./packages/default.nix
          ./hosts/scarab/default.nix
          ./users/stitchynyan/default.nix
        ];
      };
      lappy = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [
          nixos-hardware.nixosModules.framework-12th-gen-intel

          ./packages/default.nix
          ./hosts/lappy/default.nix
          ./users/stitchynyan/default.nix

          home-manager.nixosModules.home-manager
          {
             home-manager.extraSpecialArgs = {inherit inputs;};
             home-manager.useGlobalPkgs = true;
             home-manager.useUserPackages = true;
             home-manager.users.stitchynyan = import ./users/stitchynyan/home.nix;
          }
        ];
      };
      gemini = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [

          ./packages/default.nix
          ./hosts/gemini/default.nix
          ./users/nyadmin/default.nix

          home-manager.nixosModules.home-manager
          {
             home-manager.extraSpecialArgs = {inherit inputs;};
             home-manager.useGlobalPkgs = true;
             home-manager.useUserPackages = true;
             home-manager.users.nyadmin = import ./users/nyadmin/home.nix;
          }
        ];
      };
    };
  };

  inputs = {
    home-manager = {
      url = "github:nix-community/home-manager/master";
        inputs.nixpkgs.follows = "nixpkgs";
    };
    mobile-nixos = {
      url = "github:nixos/mobile-nixos";
      flake = false;
    };
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    nixos-hardware.url = "github:Nixos/nixos-hardware/master";
    osu-nixos.url = "github:Asqiir/osu-nixos";
  };
}
